@@ -117,8 +117,8 @@ execute(t, flags)
 			shf_fprintf(shl_out, "%s",
 				PS4_SUBSTITUTE(str_val(global("PS4"))));
 			for (i = 0; ap[i]; i++)
-				shf_fprintf(shl_out, "%s%s", ap[i],
-					ap[i + 1] ? space : newline);
+				shf_fprintf(shl_out, "%s%c", ap[i],
+					ap[i + 1] ? ' ' : '\n');
 			shf_flush(shl_out);
 		}
 		if (ap[0])
@@ -445,36 +445,16 @@ execute(t, flags)
  */
 
 static int
-comexec(t, tp, ap, flags)
-	struct op *t;
-	struct tbl *volatile tp;
-	char **ap;
-	int volatile flags;
+comexec(struct op *t, struct tbl *volatile tp, char **ap, int volatile flags)
 {
 	int i;
 	int rv = 0;
 	char *cp;
-/*	register char **lastp; */
 	static struct op texec; /* Must be static (XXX but why?) */
 	int type_flags;
 	int keepasn_ok;
 	int fcflags = FC_BI|FC_FUNC|FC_PATH;
 
-#ifdef KSH
-	/* snag the last argument for $_ XXX not the same as at&t ksh,
-	 * which only seems to set $_ after a newline (but not in
-	 * functions/dot scripts, but in interactive and scipt) -
-	 * perhaps save last arg here and set it in shell()?.
-	 */
-	if (Flag(FTALKING) && *(lastp = ap)) {
-		while (*++lastp)
-			;
-		/* setstr() can't fail here */
-		setstr(typeset("_", LOCAL, 0, INTEGER, 0), *--lastp,
-		       KSH_RETURN_ERROR);
-	}
-#endif /* KSH */
-
 	/* Deal with the shell builtins builtin, exec and command since
 	 * they can be followed by other commands.  This must be done before
 	 * we know if we should create a local block, which must be done
@@ -553,11 +533,8 @@ comexec(t, tp, ap, flags)
 	else {
 		/* create new variable/function block */
 		newblock();
-		/* ksh functions don't keep assignments, POSIX functions do. */
-		if (keepasn_ok && tp && tp->type == CFUNC)
-			type_flags = 0;
-		else
-			type_flags = LOCAL|LOCAL_COPY|EXPORT;
+
+		type_flags = LOCAL|LOCAL_COPY|EXPORT;
 
 	}
 	if (Flag(FEXPORT))
@@ -568,8 +545,8 @@ comexec(t, tp, ap, flags)
 			if (i == 0)
 				shf_fprintf(shl_out, "%s",
 					PS4_SUBSTITUTE(str_val(global("PS4"))));
-			shf_fprintf(shl_out, "%s%s", cp,
-				t->vars[i + 1] ? space : newline);
+			shf_fprintf(shl_out, "%s%c", cp,
+				t->vars[i + 1] ? ' ' : '\n');
 			if (!t->vars[i + 1])
 				shf_flush(shl_out);
 		}
@@ -739,9 +716,7 @@ comexec(t, tp, ap, flags)
 }
 
 static void
-scriptexec(tp, ap)
-	register struct op *tp;
-	register char **ap;
+scriptexec(struct op *tp, char **ap)
 {
 	char *shell;
 
@@ -765,32 +740,16 @@ scriptexec(tp, ap)
 			(void) close(fd);
 		}
 		if ((buf[0] == '#' && buf[1] == '!' && (cp = &buf[2]))
-# ifdef OS2
-		    || (strncmp(buf, "extproc", 7) == 0 && isspace(buf[7])
-			&& (cp = &buf[7]))
-# endif /* OS2 */
 		    )
 		{
 			while (*cp && (*cp == ' ' || *cp == '\t'))
 				cp++;
 			if (*cp && *cp != '\n') {
 				char *a0 = cp, *a1 = (char *) 0;
-# ifdef OS2
-				char *a2 = cp;
-# endif /* OS2 */
 
 				while (*cp && *cp != '\n' && *cp != ' '
 				       && *cp != '\t')
 				{
-# ifdef OS2
-			/* Allow shell search without prepended path
-			 * if shell with / in pathname cannot be found.
-			 * Use / explicitly so \ can be used if explicit
-			 * needs to be forced.
-			 */
-					if (*cp == '/')
-						a2 = cp + 1;
-# endif /* OS2 */
 					cp++;
 				}
 				if (*cp && *cp != '\n') {
@@ -809,38 +768,9 @@ scriptexec(tp, ap)
 					*cp = '\0';
 					if (a1)
 						*tp->args-- = a1;
-# ifdef OS2
-					if (a0 != a2) {
-						char *tmp_a0 = str_nsave(a0,
-							strlen(a0) + 5, ATEMP);
-						if (search_access(tmp_a0, X_OK,
-								(int *) 0))
-							a0 = a2;
-						afree(tmp_a0, ATEMP);
-					}
-# endif /* OS2 */
 					shell = a0;
 				}
 			}
-# ifdef OS2
-		} else {
-		        /* Use ksh documented shell default if present
-			 * else use OS2_SHELL which is assumed to need
-			 * the /c option and '\' as dir separater.
-			 */
-		         char *p = shell;
-
-			 shell = str_val(global("EXECSHELL"));
-			 if (shell && *shell)
-				 shell = search(shell, path, X_OK, (int *) 0);
-			 if (!shell || !*shell) {
-				 shell = p;
-				 *tp->args-- = "/c";
-				 for (p = tp->str; *p; p++)
-					 if (*p == '/')
-						 *p = '\\';
-			 }
-# endif /* OS2 */
 		}
 	}
 #endif	/* SHARPBANG */
@@ -853,10 +783,9 @@ scriptexec(tp, ap)
 }
 
 int
-shcomexec(wp)
-	register char **wp;
+shcomexec(char **wp)
 {
-	register struct tbl *tp;
+	struct tbl *tp;
 
 	tp = transitional_tsearch(&builtins.root, *wp);
 	if (tp == NULL)
@@ -895,9 +824,7 @@ findfunc(const char *name, int create)
  * function did not exist, returns 0 otherwise.
  */
 int
-define(name, t)
-	const char *name;
-	struct op *t;
+define(const char *name, struct op *t)
 {
 	struct tbl *tp;
 	int was_set = 0;
@@ -938,10 +865,7 @@ define(name, t)
  * add builtin
  */
 void
-builtin(name, func, flags)
-	const char *name;
-	int (*func) ARGS((int, char **, int));
-	int flags;
+builtin(const char *name, int (*func) (int, char **, int), int flags)
 {
 	struct tbl *tp;
 
@@ -1042,7 +966,6 @@ search_access(path, mode, errnop)
 	int mode;
 	int *errnop;		/* set if candidate found, but not suitable */
 {
-#ifndef OS2
 	int ret, err = 0;
 	struct stat statb;
 
@@ -1062,74 +985,8 @@ search_access(path, mode, errnop)
 	if (err && errnop && !*errnop)
 		*errnop = err;
 	return ret;
-#else /* !OS2 */
-	/*
-	 * NOTE: ASSUMES path can be modified and has enough room at the
-	 *       end of the string for a suffix (ie, 4 extra characters).
-	 *	 Certain code knows this (eg, eval.c(globit()),
-	 *	 exec.c(search())).
-	 */
-	static char *xsuffixes[] = { ".ksh", ".exe", ".", ".sh", ".cmd",
-				     ".com", ".bat", (char *) 0
-				   };
-	static char *rsuffixes[] = { ".ksh", ".", ".sh", ".cmd", ".bat",
-				      (char *) 0
-				   };
-	int i;
-	char *mpath = (char *) path;
-	char *tp = mpath + strlen(mpath);
-	char *p;
-	char **sfx;
- 
-	/* If a suffix has been specified, check if it is one of the
-	 * suffixes that indicate the file is executable - if so, change
-	 * the access test to R_OK...
-	 * This code assumes OS/2 files can have only one suffix...
-	 */
-	if ((p = strrchr((p = ksh_strrchr_dirsep(mpath)) ? p : mpath, '.'))) {
-		if (mode == X_OK) 
-			mode = R_OK;
-		return search_access1(mpath, mode, errnop);
-	}
-	/* Try appending the various suffixes.  Different suffixes for
-	 * read and execute 'cause we don't want to read an executable...
-	 */
-	sfx = mode == R_OK ? rsuffixes : xsuffixes;
-	for (i = 0; sfx[i]; i++) {
-		strcpy(tp, p = sfx[i]);
-		if (search_access1(mpath, R_OK, errnop) == 0)
-			return 0;
-		*tp = '\0';
-	}
-	return -1;
-#endif /* !OS2 */
 }
 
-#ifdef OS2
-static int
-search_access1(path, mode, errnop)
-	const char *path;
-	int mode;
-	int *errnop;		/* set if candidate found, but not suitable */
-{
-	int ret, err = 0;
-	struct stat statb;
-
-	if (stat(path, &statb) < 0)
-		return -1;
-	ret = eaccess(path, mode);
-	if (ret < 0)
-		err = errno; /* File exists, but we can't access it */
-	else if (!S_ISREG(statb.st_mode)) {
-		ret = -1;
-		err = S_ISDIR(statb.st_mode) ? EISDIR : EACCES;
-	}
-	if (err && errnop && !*errnop)
-		*errnop = err;
-	return ret;
-}
-#endif /* OS2 */
-
 /*
  * search for command with PATH
  */
@@ -1147,25 +1004,6 @@ search(name, path, mode, errnop)
 
 	if (errnop)
 		*errnop = 0;
-#ifdef OS2
-	/* Xinit() allocates 8 additional bytes, so appended suffixes won't
-	 * overflow the memory.
-	 */
-	namelen = strlen(name) + 1;
-	Xinit(xs, xp, namelen, ATEMP);
-	memcpy(Xstring(xs, xp), name, namelen);
-
- 	if (ksh_strchr_dirsep(name)) {
-		if (search_access(Xstring(xs, xp), mode, errnop) >= 0)
-			return Xstring(xs, xp); /* not Xclose() - see above */
-		Xfree(xs, xp);
-		return NULL;
-	}
-
-	/* Look in current context always. (os2 style) */
-	if (search_access(Xstring(xs, xp), mode, errnop) == 0) 
-		return Xstring(xs, xp); /* not Xclose() - xp may be wrong */
-#else /* OS2 */
 	if (ksh_strchr_dirsep(name)) {
 		if (search_access(name, mode, errnop) == 0)
 			return (char *) name;
@@ -1174,7 +1012,6 @@ search(name, path, mode, errnop)
 
 	namelen = strlen(name) + 1;
 	Xinit(xs, xp, 128, ATEMP);
-#endif /* OS2 */
 
 	sp = path;
 	while (sp != NULL) {
@@ -1191,11 +1028,7 @@ search(name, path, mode, errnop)
 		XcheckN(xs, xp, namelen);
 		memcpy(xp, name, namelen);
  		if (search_access(Xstring(xs, xp), mode, errnop) == 0)
-#ifdef OS2
- 			return Xstring(xs, xp); /* Not Xclose() - see above */
-#else /* OS2 */
 			return Xclose(xs, xp + namelen);
-#endif /* OS2 */
 		if (*sp++ == '\0')
 			sp = NULL;
 	}
@@ -1237,7 +1070,7 @@ iosetup(struct ioword *iop, struct tbl UNUSED(*tp))
 	int u = -1;
 	char *cp = iop->name;
 	int iotype = iop->flag & IOTYPE;
-	int do_open = 1, do_close = 0, UNINITIALIZED(flags);
+	int do_open = 1, do_close = 0, flags = 0;
 	struct ioword iotmp;
 	struct stat statb;
 
@@ -1246,7 +1079,7 @@ iosetup(struct ioword *iop, struct tbl UNUSED(*tp))
 
 	/* Used for tracing and error messages to print expanded cp */
 	iotmp = *iop;
-	iotmp.name = (iotype == IOHERE) ? (char *) 0 : cp;
+	iotmp.name = (iotype == IOHERE) ? NULL : cp;
 	iotmp.flag |= IONAMEXP;
 
 	if (Flag(FXTRACE))
@@ -1305,10 +1138,6 @@ iosetup(struct ioword *iop, struct tbl UNUSED(*tp))
 	}
 	if (do_open) {
 		u = open(cp, flags, 0666);
-#ifdef OS2
-		if (u < 0 && strcmp(cp, "/dev/null") == 0)
-			u = open("nul", flags, 0666);
-#endif /* OS2 */
 	}
 	if (u < 0) {
 		/* herein() may already have printed message */
@@ -1364,9 +1193,7 @@ iosetup(struct ioword *iop, struct tbl UNUSED(*tp))
  * if unquoted here, expand here temp file into second temp file.
  */
 static int
-herein(content, sub)
-	const char *content;
-	int sub;
+herein(const char *content, int sub)
 {
 	volatile int fd = -1;
 	struct source *s, *volatile osource;
