@@ -525,7 +525,7 @@ static void ers_walk(const void *nodep, const VISIT which, const int UNUSED(dept
 						/* at&t ksh can't have justified integers.. */
 						shprintf("%s", s);
 					}
-					shprintf(newline);
+					shprintf("\n");
 				}
 				/* Only report first `element' of an array with
 				 * no set elements.
@@ -793,10 +793,10 @@ int posh_builtin_kill(int argc, char **argv, int UNUSED(flags))
 			}
 		} else {
 			p = null;
-			for (i = 1; i < SIGNALS; i++, p = space)
+			for (i = 1; i < SIGNALS; i++, p = " ")
 				if (sigtraps[i].name)
 					shprintf("%s%s", p, sigtraps[i].name);
-			shprintf(newline);
+			shprintf("\n");
 		}
 		return 0;
 	}
